@@ -14,6 +14,9 @@
 #' @param percentages_only tabulate percentages of the focal DV value only
 #' @param counts_only tabulate counts of the focal DV value only
 #' @param sigfigs number of significant digits to round to
+#' @param chi_sq_test_stats if \code{chi_sq_test_stats = TRUE},
+#' chi-square test statistic and degrees of freedom will be included
+#' in the pairwise comparison data.table.
 #' @examples
 #' chi_square_test_pairwise(data = mtcars, iv_name = "vs", dv_name = "am")
 #' chi_square_test_pairwise(data = mtcars, iv_name = "vs", dv_name = "am",
@@ -26,7 +29,8 @@ chi_square_test_pairwise <- function(
   focal_dv_value = NULL,
   percentages_only = NULL,
   counts_only = NULL,
-  sigfigs = 3
+  sigfigs = 3,
+  chi_sq_test_stats = FALSE
 ) {
   # bind the vars locally to the function
   iv <- dv <- NULL
@@ -93,10 +97,26 @@ chi_square_test_pairwise <- function(
         paste0(c("grp_1, count of ", "grp_2, count of "), focal_dv_value)
     }
   }
+  # chi square test results
+  chi_sq_test_results <- lapply(seq_len(nrow(dt02)), function(i) {
+    dt03 <- dt01[iv %in% dt02[i, ]]
+    stats::chisq.test(
+      dt03$iv, dt03$dv, correct = FALSE)
+  })
+  # chi square test stats
+  if (chi_sq_test_stats == TRUE) {
+    # chi-square test df
+    chi_sq_test_df <- vapply(seq_len(nrow(dt02)), function(i) {
+      chi_sq_test_results[[i]][["parameter"]][["df"]]
+    }, FUN.VALUE = numeric(1L))
+    # chi-square test stat
+    chi_sq_test_stat <- vapply(seq_len(nrow(dt02)), function(i) {
+      chi_sq_test_results[[i]][["statistic"]]
+    }, FUN.VALUE = numeric(1L))
+  }
   # chi-square test p values
   chi_sq_p_value <- vapply(seq_len(nrow(dt02)), function(i) {
-    dt03 <- dt01[iv %in% dt02[i, ]]
-    stats::chisq.test(dt03$iv, dt03$dv, correct = FALSE)[["p.value"]]
+    chi_sq_test_results[[i]][["p.value"]]
   }, FUN.VALUE = numeric(1L))
   # bonferroni
   bonferroni_sig <- ifelse(
@@ -106,5 +126,14 @@ chi_square_test_pairwise <- function(
     dt02, section_2, chi_sq_p_value =
       kim::pretty_round_p_value(chi_sq_p_value),
     bonferroni_sig)
+  # add chi square test stats
+  if (chi_sq_test_stats == TRUE) {
+    output <- data.table::data.table(
+      dt02, section_2,
+      chi_sq_test_df,
+      chi_sq_test_stat = signif(chi_sq_test_stat, sigfigs),
+      chi_sq_p_value = kim::pretty_round_p_value(chi_sq_p_value),
+      bonferroni_sig)
+  }
   return(output)
 }
